API docs for “spamfighter.core.commands.test.test_command.FakeSerializable”

# Class s.c.c.t.t.FakeSerializable(object):

Part of spamfighter.core.commands.test.test_command View Source View In Hierarchy

Undocumented

Method | __init__ | Undocumented
Method | serialize | Undocumented
Class Method | unserialize | Undocumented

def __init__(self, value): (source)
Undocumented
def serialize(self): (source)
Undocumented
@classmethod
def unserialize(cls, serialized): (source)
Undocumented